==> qingcloud-cli-0.9.8.tar.gz: qingcloud-cli-0.9.8/qingcloud/cli/iaas_client/actions/monitor/get_loadbalancer_monitoring_data.py <==
# coding: utf-8

from qingcloud.cli.iaas_client.actions.base import BaseAction
from qingcloud.cli.misc.utils import explode_array, convert_to_utctime

class GetLoadBalancerMonitorAction(BaseAction):

    action = 'GetLoadBalancerMonitor'
    command = 'get-loadbalancer-monitoring-data'
    usage = '%(prog)s -r <resource> -m <meters> -s <step> -b <start_time> -e <end_time> [-f <conf_file>]'
    description = 'Get load balancer related resource monitoring data.'

    @classmethod
    def add_ext_arguments(cls, parser):

        parser.add_argument('-r', '--resource', dest='resource',
                action='store', type=str, default=None,
                help='the ID of resource, can be loadbalancer_id, listener_id or backend_id.')

        parser.add_argument('-m', '--meters', dest='meters',
                action='store', type=str, default=None,
                help='''list of metering types you want to get.
                If resouce is loadbalancer, meter should be "traffic",
                otherwise meter should be "request".
                ''')

        parser.add_argument('-s', '--step', dest='step',
                action='store', type=str, default=None,
                help='the metering time step, valid steps: "5m", "15m", "30m", "1h", "2h", "1d".')

        parser.add_argument('-b', '--start_time', dest='start_time',
                action='store', type=str, default=None,
                help='the start time stamp in the format YYYY-MM-DD hh:mm:ss.')

        parser.add_argument('-e', '--end_time', dest='end_time',
                action='store', type=str, default=None,
                help='the end time stamp in the format YYYY-MM-DD hh:mm:ss.')

    @classmethod
    def build_directive(cls, options):
        start_time = convert_to_utctime(options.start_time)
        end_time = convert_to_utctime(options.end_time)
        required_params = {
                'resource': options.resource,
                'meters': options.meters,
                'step': options.step,
                'start_time': start_time,
                'end_time': end_time,
                }
        for param in required_params:
            if required_params[param] is None or required_params[param] == '':
                print 'error: [%s] should be specified' % param
                return None

        return {
                'resource': options.resource,
                'meters': explode_array(options.meters),
                'step': options.step,
                'start_time': start_time,
                'end_time': end_time,
                }

==> qingcloud-cli-0.9.9.tar.gz: qingcloud-cli-0.9.9/qingcloud/cli/iaas_client/actions/monitor/get_loadbalancer_monitoring_data.py <==
# coding: utf-8

from qingcloud.cli.iaas_client.actions.base import BaseAction
from qingcloud.cli.misc.utils import explode_array, convert_to_utctime

class GetLoadBalancerMonitorAction(BaseAction):

    action = 'GetLoadBalancerMonitor'
    command = 'get-loadbalancer-monitoring-data'
    usage = '%(prog)s -r <resource> -m <meters> -s <step> -b <start_time> -e <end_time> [-f <conf_file>]'
    description = 'Get load balancer related resource monitoring data.'

    @classmethod
    def add_ext_arguments(cls, parser):

        parser.add_argument('-r', '--resource', dest='resource',
                action='store', type=str, default=None,
                help='the ID of resource, can be loadbalancer_id, listener_id or backend_id.')

        parser.add_argument('-m', '--meters', dest='meters',
                action='store', type=str, default=None,
                help='''list of metering types you want to get.
                If resouce is loadbalancer, meter should be "traffic",
                otherwise meter should be "request".
                ''')

        parser.add_argument('-s', '--step', dest='step',
                action='store', type=str, default=None,
                help='the metering time step, valid steps: "5m", "15m", "30m", "1h", "2h", "1d".')

        parser.add_argument('-b', '--start_time', dest='start_time',
                action='store', type=str, default=None,
                help='the start time stamp in the format YYYY-MM-DD hh:mm:ss.')

        parser.add_argument('-e', '--end_time', dest='end_time',
                action='store', type=str, default=None,
                help='the end time stamp in the format YYYY-MM-DD hh:mm:ss.')

        parser.add_argument('--decompress', dest='decompress',
                action='store_true',
                help='decompress mointoring data from api.')

    @classmethod
    def build_directive(cls, options):
        start_time = convert_to_utctime(options.start_time)
        end_time = convert_to_utctime(options.end_time)
        required_params = {
                'resource': options.resource,
                'meters': options.meters,
                'step': options.step,
                'start_time': start_time,
                'end_time': end_time,
                }
        for param in required_params:
            if required_params[param] is None or required_params[param] == '':
                print 'error: [%s] should be specified' % param
                return None

        return {
                'resource': options.resource,
                'meters': explode_array(options.meters),
                'step': options.step,
                'start_time': start_time,
                'end_time': end_time,
                'decompress': options.decompress,
                }
